`<Badge />` component wraps the element you want to apply a badge to. It is based on the [Badge component from Material-UI](https://v4.mui.com/api/badge/).

### Basic Badges

The default version of badges is used to indicate an amount of new things that the user should see. This could be a number of new messages in an inbox or the number of new files in a folder.

The `dot` variant can be used to indicate that the item _itself_ is new. A `dot` badge on a folder for example indicates that the folder is new, not that it contains new elements.

```jsx
import Badge from 'cozy-ui/transpiled/react/Badge'
import Icon from 'cozy-ui/transpiled/react/Icon'
import Variants from 'cozy-ui/docs/components/Variants'
import CircleFilledIcon from "cozy-ui/transpiled/react/Icons/CircleFilled"

const initialVariants = [
  { overlap: true, dot: false, withBorder: false, left: false, bottom: false, small: false, large: false }
]

const DemoBadge = ({ variant, ...props }) => {
  return (
    <Badge
      {...props}
      className="u-m-half"
      badgeContent={4}
      variant={variant.dot ? "dot" : "standard"}
      size={variant.large ? "large" : variant.small ? "small" : "medium"}
      anchorOrigin={{
        vertical: variant.bottom ? "bottom" : "top",
        horizontal: variant.left ? "left" : "right",
      }}
      withBorder={variant.withBorder}
      overlap={variant.overlap ? "circular" : "rectangular"}
    >
      <Icon
        icon={CircleFilledIcon}
        size={variant.large ? "32" : variant.small ? "16" : "24"}
        color="var(--slateGrey)"
      />
    </Badge>
  )
}

;

<Variants initialVariants={initialVariants} screenshotAllVariants>
  {variant => (
    <>
      <DemoBadge variant={variant} color="default" />
      <DemoBadge variant={variant} color="primary" />
      <DemoBadge variant={variant} color="secondary" />
      <DemoBadge variant={variant} color="success" />
      <DemoBadge variant={variant} color="error" />
      <DemoBadge variant={variant} color="warning" />
      <DemoBadge variant={variant} color="info" />
    </>
  )}
</Variants>
```

### Double badges

Badges can be combined — in this example, we have an item with a new qualification.

```jsx
import Badge from 'cozy-ui/transpiled/react/Badge'
import InfosBadge from 'cozy-ui/transpiled/react/InfosBadge'
import Icon from 'cozy-ui/transpiled/react/Icon'
import Avatar from 'cozy-ui/transpiled/react/legacy/Avatar'
import LinkIcon from "cozy-ui/transpiled/react/Icons/Link"

;

<InfosBadge
  badgeContent={
    <Badge color="error" variant="dot" size="small">
      <Icon icon={LinkIcon} size={isTwakeTheme() ? 16 : 10} />
    </Badge>
  }
>
  <Avatar text="CD" size={isTwakeTheme() ? 'medium' : 'small'} />
</InfosBadge>
```
