import _slicedToArray from "@babel/runtime/helpers/slicedToArray";
import { useState, useCallback, useEffect } from 'react';
/**
 * When calling setPrev when we are at index min, goes to max
 * When calling setNext when we are at index max, goes to min
 *
 * @param  {number} initialState - If initialState becomes defined (undefined -> value),
 * index will be set to value (useful when the initial state is not known yet)
 * @param  {number} min
 * @param  {number} max
 * @return {Array} - [index, setPrev, setNext]
 */

var useCycle = function useCycle(initialState, min, max) {
  var _useState = useState(initialState),
      _useState2 = _slicedToArray(_useState, 2),
      curIndex = _useState2[0],
      setIndex = _useState2[1];

  var handlePrev = useCallback(function () {
    var prev = curIndex - 1;
    setIndex(prev < min ? max : prev);
  }, [curIndex, min, max]);
  var handleNext = useCallback(function () {
    var next = curIndex + 1;
    setIndex(next > max ? min : next);
  }, [curIndex, max, min]); // If the initialState is not initially set, the index will be undefined and
  // when it becomes defined, index will be set to the defined initialState value

  useEffect(function () {
    if (curIndex === undefined && initialState !== undefined) {
      setIndex(initialState);
    }
  }, [curIndex, initialState]);
  return [curIndex, handlePrev, handleNext];
};

export default useCycle;